#
# spec file for package kio_audiocd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname audiocd-kio
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kio_audiocd
Version:        22.12.3
Release:        bp155.1.5
Summary:        KDE I/O Slave for Audio CDs
License:        GPL-2.0-or-later
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  alsa-devel
BuildRequires:  cdparanoia-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  flac-devel
BuildRequires:  libvorbis-devel
BuildRequires:  cmake(KF5Cddb)
BuildRequires:  cmake(KF5CompactDisc)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Cddb)
BuildRequires:  cmake(Phonon4Qt5)

%description
This package contains an KIO slave to access audio CDs.

%package devel
Summary:        Development package for kio_audiocd
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}

%description devel
This package contains the development files for the audiocd kio slave

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name
%{kf5_find_htmldocs}

%ldconfig_scriptlets

%files
%license COPYING*
%doc %lang(en) %{_kf5_htmldir}/en/kioslave5/audiocd/
%doc %lang(en) %{_kf5_htmldir}/en/kcontrol/audiocd/
%dir %{_kf5_sharedir}/konqsidebartng
%dir %{_kf5_sharedir}/konqsidebartng/virtual_folders
%dir %{_kf5_sharedir}/konqsidebartng/virtual_folders/services
%dir %{_kf5_sharedir}/solid
%dir %{_kf5_sharedir}/solid/actions
%{_kf5_appstreamdir}/org.kde.kio_audiocd.metainfo.xml
%{_kf5_configkcfgdir}/audiocd_*_encoder.kcfg
%{_kf5_debugdir}/kio_audiocd.categories
%{_kf5_debugdir}/kio_audiocd.renamecategories
%{_kf5_libdir}/libaudiocdplugins.so.*
%{_kf5_plugindir}/kcm_audiocd.so
%{_kf5_plugindir}/kf5/kio/audiocd.so
%{_kf5_plugindir}/libaudiocd_encoder_*.so
%{_kf5_servicesdir}/audiocd.desktop
%{_kf5_sharedir}/konqsidebartng/virtual_folders/services/audiocd.desktop
%{_kf5_sharedir}/solid/actions/solid_audiocd.desktop

%files devel
%{_includedir}/audiocdencoder.h
%{_includedir}/audiocdplugins_export.h
%{_kf5_libdir}/libaudiocdplugins.so

%files lang -f %{name}.lang

%changelog
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Clean up define
  * add missing include
  * Add CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * const'ify + use std::as_const here
  * Modernize code
  * Const'ify variable
  * Remove some clazy warning
  * Now we depend against qt5.15
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Remove obsolete .protocol file
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Changes since 20.12.3:
  * Remove unused include
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Changes since 20.08.3:
  * Add missing kdoctools_install
  * Use systemsettings5 instead of kcmshell5
  * Add I18N context for the "Missing device specification" message
  * Update to work properly with current KIO
  * Search all possible locations for plugins
  * Use CamelCase includes (scripted)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * appdata: use canonical help URL
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- No code change since 20.04.3
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Make it compile against qt5.15
  * Use nullptr here
  * Remove endl at the end of qDebug
  * Use URLs with transport encryption
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Fix compilation with Qt 5.15
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- No code change since 19.12.0
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- No code change since 19.11.90
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Make it compiles without deprecated method
  * Port away from QRegExp to QRegularExpression
  * use a valid category
  * rename for spec compliance
  * complete appstream file for kde.org/applications goodness
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Add missing ShowPreviews key to audiocd.json
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Get rid of obsolete QString::null
  * Fix typo, remove extra QByteArray() (thanks to Albert Astals Cid)
  * Use new logging category directory when ECM>=5.59
  * Use new syntax
  * Make audiocd:/ conformant with other KIO from KF5 by adding JSON file
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Use Unicode by default for CD-info data (kde#406262)
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Use the correct MIME type for CDDB information.txt (kde#405783)
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Fix stat to actually recognize the info dir exists
  * Use more https in links
  * Include KDECMakeSettings & KDECompilerSettings first
  * Use KF_MIN_VERSION also for ECM, given it's released as part of KF now
  * Bump min cmake version to 3.0
  * Remove not existing include dir
  * Install kio binary into kf5/kio subdir, like other kio binaries
  * Fix minor typos
  * Add Audiocd KCM docs
  * Use override as suggested by compiler
  * Use tabs consistently, add some initialization (do not know if it works).
  * Add Opus support for KIO AudioCD (kde#313768)
  * Use more loose permissions for the ripped files (kde#203183)
  * Fix KCM installation
  * Fix minor typos and antics
  * Add Mainpage.dox to test Doxygen documentation with Krazy
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Remove incorrect <provides><library> from appdata, not a real library
  * Call KLocalizedString::setApplicationDomain only after QApp instance done
  * Fix Ogg Vorbis logic for Average and Min/Max bitrates
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix KCM installation
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix switching between quality and bitrate for Vorbis Ogg plugin
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Use the current date and time for the created files to avoid confusions (kde#400114)
  * Fix switching between constant and variable bitrate for LAME configuration module (kde#386014)
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Use the right version of kcmshell (kde#398368)
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * generate and use a local cdda_interface headerfile copy
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Restore entity &etc;
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * None
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * None
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Use kioclient5 instead of kioclient from KDE 4.x (kde#373819)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * None
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Sun Nov 18 2012 hrvoje.senjan@gmail.com
- Enable flac and ogg encoders
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
* Tue Sep  4 2012 toddrme2178@gmail.com
- Update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Tue Jul 31 2012 toddrme2178@gmail.com
- Update to 4.9.0
  * see http://kde.org/announcements/4.9/ for details
* Thu Jul 19 2012 toddrme2178@gmail.com
- update to 4.8.97
  * RC2 milestone release of KDE 4.9
  * see http://kde.org/announcements/announce-4.9-rc2.php for details
* Fri Jun 29 2012 tittiatcoke@gmail.com
- Update to 4.8.95_20120629
* Sun Jun 17 2012 tittiatcoke@gmail.com
- Update to 4.8.90_20120617
* Tue May 29 2012 tittiatcoke@gmail.com
- Update to 4.8.80_20120529
* Sun May 13 2012 tittiatcoke@gmail.com
- Update to 4.8.42_20120513
* Sun May  6 2012 tittiatcoke@gmail.com
- Update to 4.8.42_20120506
* Tue Nov 22 2011 tittiatcoke@gmail.com
- Update to 4.7.80_20111122
* Sun Nov 20 2011 tittiatcoke@gmail.com
- Update to 4.7.80_20111120
* Fri Nov 18 2011 tittiatcoke@gmail.com
- Update to 4.7.80_20111118
* Wed Nov 16 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111116
* Tue Nov 15 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111115
* Mon Nov 14 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111114
* Sun Nov 13 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111113
* Fri Nov 11 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111111
* Mon Nov  7 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111107
* Sun Nov  6 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111106
* Fri Nov  4 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111104
* Thu Nov  3 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111103
* Tue Nov  1 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111101
* Mon Oct 31 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111031
* Sat Oct 29 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111029
* Fri Oct 28 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111028
* Wed Oct 26 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111026
* Tue Oct 25 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111025
* Mon Oct 24 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111024
* Sun Oct 23 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111023
* Fri Oct 21 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111021
* Wed Oct 19 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111019
* Tue Oct 18 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111018
* Mon Oct 17 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111017
* Mon Oct 17 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111017
* Sun Oct 16 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111016
* Sat Oct 15 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111015
* Fri Oct 14 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111014
* Thu Oct 13 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111013
* Wed Oct 12 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111012
* Tue Oct 11 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111011
* Mon Oct 10 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111010
* Sun Oct  9 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111009
* Fri Oct  7 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111007
* Wed Oct  5 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111005
* Tue Oct  4 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111004
* Mon Oct  3 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111003
* Sun Oct  2 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111002
* Sat Oct  1 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111001
* Thu Sep 29 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20110929
* Wed Sep 28 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20110928
* Tue Sep 27 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110927
* Sun Sep 25 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110925
* Sat Sep 24 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110924
* Thu Sep 22 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110922
* Wed Sep 21 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110921
* Tue Sep 20 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110920
* Sun Sep 18 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110918
* Fri Sep 16 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110916
* Thu Sep 15 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110915
* Tue Sep 13 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110913
* Tue Sep 13 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110913
* Mon Sep 12 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110912
* Mon Sep 12 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110912
* Fri Sep  9 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110909
* Wed Sep  7 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110907
* Tue Sep  6 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110906
* Sun Sep  4 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110904
* Sat Sep  3 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110903
* Fri Sep  2 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110902
* Thu Sep  1 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110901
* Tue Aug 30 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110830
* Mon Aug 29 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110829
* Sun Aug 28 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110828
* Sat Aug 27 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110827
* Fri Aug 26 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110826
* Thu Aug 25 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110825
* Tue Aug 23 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110823
* Mon Aug 22 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110822
* Sun Aug 21 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110821
* Sat Aug 20 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110820
* Fri Aug 19 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110819
* Thu Aug 18 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110818
* Wed Aug 17 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110817
* Wed Aug 17 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110817
* Tue Aug 16 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110816
* Thu Aug 11 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110811
* Wed Aug 10 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110810
* Tue Aug  9 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110809
* Sun Aug  7 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110807
* Fri Aug  5 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110805
* Thu Aug  4 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110804
* Wed Aug  3 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110803
* Tue Aug  2 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110802
* Tue Aug  2 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110802
* Mon Aug  1 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110801
* Fri Jul 29 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110729
* Wed Jul 27 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110727
* Mon Jul 25 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110725
* Sun Jul 24 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110724
* Sun Jul 24 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110724
* Fri Jul 22 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110722
* Thu Jul 21 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110721
* Thu Jul 21 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110721
* Wed Jul 20 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110720
* Tue Jul 19 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110719
* Mon Jul 18 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110718
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110717
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110717
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110717
* Thu Jul 14 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110714
* Mon Jul  4 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110704
* Tue Jun 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110621
* Mon Jun 20 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110620
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Wed Jun 15 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110615
* Tue Jun 14 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110614
* Mon Jun 13 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110613
* Sun Jun 12 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110612
* Sat Jun 11 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110611
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Mon Jun  6 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110606
* Sun Jun  5 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110605
* Sat Jun  4 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110604
* Fri Jun  3 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110603
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Wed Jun  1 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110601
* Tue May 31 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110531
* Mon May 30 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110530
* Sat May 28 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110528
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Wed May 25 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110525
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Mon May 23 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110523
* Sat May 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110521
* Fri May 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110520
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Wed May 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110518
* Tue May 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110517
* Mon May 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110516
* Sun May 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110515
* Sat May 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110514
* Fri May 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110513
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Wed May 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110511
* Tue May 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110510
* Mon May  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110509
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Sat May  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110507
* Fri May  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110506
* Thu May  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110505
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Tue May  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110503
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110430
* Fri Apr 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110429
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Fri Apr 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110422
* Thu Apr 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110421
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Tue Apr 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110419
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sat Apr 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110416
* Fri Apr 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110415
* Thu Apr 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110414
* Wed Apr 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110413
* Tue Apr 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110412
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110411
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to .._20110411
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sat Apr  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110409
* Fri Apr  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110408
* Thu Apr  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110407
* Wed Apr  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110406
* Tue Apr  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110405
* Mon Apr  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110404
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Wed Jan  5 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Sun Nov 21 2010 coolo@novell.com
- remove patch not adapted since 4.1
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Tue Jul 27 2010 coolo@novell.com
- libakode doesn't seem to be required
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Wed May 19 2010 cmorve69@yahoo.es
- Remove __DATE__ from source so build-compare can do its work
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Thu Jan 28 2010 adrian@suse.de
- require cdparanoia-devel also for openSUSE:11.2
  (enables kio_audiocd again)
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov 16 2009 llunak@novell.com
- obsolete only old versions of kdemultimedia3-kmix (bnc#542094)
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Oct 22 2009 crrodriguez@opensuse.org
- fix Provides/Obsoletes of kmix
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: few bug fixes and translation updates
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sat Aug 15 2009 beineri@opensuse.org
- fix menu categories of juk and dragonplayer (for smaller menu)
* Mon Aug 10 2009 beineri@opensuse.org
- remove libpulse-devel build requires
* Fri Aug  7 2009 llunak@suse.cz
- solid action for audiocd:/ (bnc#505997)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Wed Jul  8 2009 wstephenson@suse.de
- Update BuildRequires for new cdparanoia-devel
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu May 14 2009 dmueller@suse.de
- fix versioned deps
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Fri Jan 16 2009 dmueller@suse.de
- fix versioned deps
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Wed Nov  5 2008 dmueller@suse.de
- add missing runtime requires for dragonplayer
* Tue Nov  4 2008 llunak@suse.cz
- assign multimedia volume shortcuts to KMix (bnc#384745)
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Mon Sep 15 2008 dmueller@suse.de
- fix requires
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Thu Jul  3 2008 dmueller@suse.de
- update to 4.0.85
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Fri May  9 2008 dmueller@suse.de
- 4_0_BRANCH.diff update:
  * remove kio progress popups in juk
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 18 2008 dmueller@suse.de
- another 4_0_BRANCH.diff update:
  * hopefully fixes kmix crash on exit (bnc#373639)
* Mon Apr 14 2008 dmueller@suse.de
- 4_0_BRANCH.diff update
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Mon Feb  4 2008 stbinner@suse.de
- port kmix-autostart.diff
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 stbinner@suse.de
- update to 4.0 release
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Sat Oct 20 2007 dmueller@suse.de
- update to 3.94.1
* Tue Oct  9 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720130
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712059
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703910
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700761
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685969
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679140
* Wed Jun 13 2007 stbinner@suse.de
- disable build of Noatun's splitplaylist (#276925)
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Fri May 25 2007 stbinner@suse.de
- split off -devel package
* Fri May 18 2007 stbinner@suse.de
- initial version in abuild
